@@ -1,119 +1,104 @@
-//@line 40 "/root/tmp/build-mozilla-thunderbird/mozilla/mail/base/content/customizeToolbar.js"
+//@line 40 "/root/tmp/build-mozilla-thunderbird/comm-1.9.1/mozilla/toolkit/content/customizeToolbar.js"
 
 const kRowMax = 4;
-const kWindowWidth = 600;
-const kWindowHeight = 400;
-const kAnimateIncrement = 50;
-const kAnimateSteps = kWindowHeight / kAnimateIncrement - 1;
-const kVSizeSlop = 5;
 
 var gToolboxDocument = null;
 var gToolbox = null;
 var gCurrentDragOverItem = null;
 var gToolboxChanged = false;
-var gPreviousMode = null;
-var gPreviousIconSize = null;
+var gToolboxIconSize = false;
+var gToolboxSheet = false;
 
 function onLoad()
 {
-  gToolbox = window.arguments[0];
+  if ("arguments" in window && window.arguments[0]) {
+    InitWithToolbox(window.arguments[0]);
+    repositionDialog();
+  }
+  else if (window.frameElement &&
+           "toolbox" in window.frameElement) {
+    gToolboxSheet = true;
+    InitWithToolbox(window.frameElement.toolbox);
+  }
+}
+
+function InitWithToolbox(aToolbox)
+{
+  gToolbox = aToolbox;
   gToolboxDocument = gToolbox.ownerDocument;
-  
-  gToolbox.addEventListener("draggesture", onToolbarDragGesture, false);
+  gToolbox.customizing = true;
+
+  gToolbox.addEventListener("dragstart", onToolbarDragStart, false);
   gToolbox.addEventListener("dragover", onToolbarDragOver, false);
-  gToolbox.addEventListener("dragexit", onToolbarDragExit, false);
-  gToolbox.addEventListener("dragdrop", onToolbarDragDrop, false);
-  repositionDialog();
+  gToolbox.addEventListener("dragleave", onToolbarDragLeave, false);
+  gToolbox.addEventListener("drop", onToolbarDrop, false);
 
   initDialog();
 }
 
-function onUnload(aEvent)
+function onClose()
 {
+  if (!gToolboxSheet)
+    window.close();
+  else
+    finishToolbarCustomization();
+}
+
+function onUnload()
+{
+  if (!gToolboxSheet)
+    finishToolbarCustomization();
+}
+
+function finishToolbarCustomization()
+{
+  gToolbox.customizing = false;
   removeToolboxListeners();
-  unwrapToolbarItems(true);
+  unwrapToolbarItems();
   persistCurrentSets();
   
   notifyParentComplete();
 }
 
-function onCancel()
-{
-  // restore the saved toolbarset for each customizeable toolbar
-  unwrapToolbarItems(false);
-  var toolbar = gToolbox.firstChild;
-  while (toolbar) {
-    if (isCustomizableToolbar(toolbar)) {
-      if (!toolbar.hasAttribute("customindex")) {
-        var previousset = toolbar.getAttribute("previousset");
-        if (previousset)
-        {
-          toolbar.currentSet = previousset;
-        }
-      }
-    }
-    toolbar = toolbar.nextSibling;
-  }
-
-  // restore the previous mode and iconsize
-  updateIconSize(gPreviousIconSize == "small");
-  updateToolbarMode(gPreviousMode);
-
-  repositionDialog();
-  gToolboxChanged = true;
-
-  return onAccept(); // we restored the default toolbar, act like a normal accept event now
-}
-
-function onAccept(aEvent)
-{
-  document.getElementById("main-box").collapsed = true;
-  window.close();
-}
-
 function initDialog()
 {
-  document.getElementById("main-box").collapsed = false;
-  
-  gPreviousMode = gToolbox.getAttribute("mode");
-  document.getElementById("modelist").value = gPreviousMode;
-  gPreviousIconSize = gToolbox.getAttribute("iconsize");
+  var mode = gToolbox.getAttribute("mode");
+  document.getElementById("modelist").value = mode;
+  gToolboxIconSize = gToolbox.getAttribute("iconsize");
   var smallIconsCheckbox = document.getElementById("smallicons");
-  if (gPreviousMode == "text")
+  smallIconsCheckbox.checked = gToolboxIconSize == "small";
+  if (mode == "text")
     smallIconsCheckbox.disabled = true;
-  else
-    smallIconsCheckbox.checked = gPreviousIconSize == "small";
 
   // Build up the palette of other items.
   buildPalette();
 
   // Wrap all the items on the toolbar in toolbarpaletteitems.
-  wrapToolbarItems(true);
+  wrapToolbarItems();
 }
 
 function repositionDialog()
 {
   // Position the dialog touching the bottom of the toolbox and centered with 
-  // it. We must resize the window smaller first so that it is positioned 
-  // properly. 
-  var screenX = gToolbox.boxObject.screenX + ((gToolbox.boxObject.width - kWindowWidth) / 2);
+  // it.
+  var width;
+  if (document.documentElement.hasAttribute("width"))
+    width = document.documentElement.getAttribute("width");
+  else
+    width = parseInt(document.documentElement.style.width);
+  var screenX = gToolbox.boxObject.screenX 
+                + ((gToolbox.boxObject.width - width) / 2);
   var screenY = gToolbox.boxObject.screenY + gToolbox.boxObject.height;
 
-  var newHeight = kWindowHeight;
-  if (newHeight >= screen.availHeight - screenY - kVSizeSlop) {
-    newHeight = screen.availHeight - screenY - kVSizeSlop;
-  }
-
-  window.resizeTo(kWindowWidth, newHeight);
   window.moveTo(screenX, screenY);
 }
 
 function removeToolboxListeners()
 {
-  gToolbox.removeEventListener("draggesture", onToolbarDragGesture, false);
+  gToolbox.removeEventListener("dragstart", onToolbarDragStart, false);
   gToolbox.removeEventListener("dragover", onToolbarDragOver, false);
-  gToolbox.removeEventListener("dragexit", onToolbarDragExit, false);
-  gToolbox.removeEventListener("dragdrop", onToolbarDragDrop, false);
+  gToolbox.removeEventListener("dragleave", onToolbarDragLeave, false);
+  gToolbox.removeEventListener("drop", onToolbarDrop, false);
 }
 
 /**
@@ -126,6 +111,13 @@ function notifyParentComplete()
     gToolbox.customizeDone(gToolboxChanged);
 }
 
+function toolboxChanged(aEvent)
+{
+  gToolboxChanged = true;
+  if ("customizeChange" in gToolbox)
+    gToolbox.customizeChange(aEvent);
+}
+
 function getToolbarAt(i)
 {
   return gToolbox.childNodes[i];
@@ -137,7 +129,7 @@ function getToolbarAt(i)
  */
 function persistCurrentSets()
 {
-  if (!gToolboxChanged)
+  if (!gToolboxChanged || gToolboxDocument.defaultView.closed)
     return;
 
   var customCount = 0;
@@ -180,24 +172,19 @@ function persistCurrentSets()
 /**
  * Wraps all items in all customizable toolbars in a toolbox.
  */
-function wrapToolbarItems(aStorePreviousSet)
+function wrapToolbarItems()
 {
   for (var i = 0; i < gToolbox.childNodes.length; ++i) {
     var toolbar = getToolbarAt(i);
     if (isCustomizableToolbar(toolbar)) {
-      if (aStorePreviousSet)
-        toolbar.setAttribute('previousset', toolbar.currentSet);
-
       for (var k = 0; k < toolbar.childNodes.length; ++k) {
         var item = toolbar.childNodes[k];
+
+//@line 225 "/root/tmp/build-mozilla-thunderbird/comm-1.9.1/mozilla/toolkit/content/customizeToolbar.js"
+
         if (isToolbarItem(item)) {
-          var nextSibling = item.nextSibling;
-          
-          var wrapper = wrapToolbarItem(item);     
-          if (nextSibling)
-            toolbar.insertBefore(wrapper, nextSibling);
-          else
-            toolbar.appendChild(wrapper);
+          var wrapper = wrapToolbarItem(item);
+          cleanupItemForToolbar(item, wrapper);
         }
       }
     }
@@ -207,47 +194,30 @@ function wrapToolbarItems(aStorePreviousSet)
 /**
  * Unwraps all items in all customizable toolbars in a toolbox.
  */
- function unwrapToolbarItems(aRemovePreviousSet)
+function unwrapToolbarItems()
 {
-  for (var i = 0; i < gToolbox.childNodes.length; ++i) {
-    var toolbar = getToolbarAt(i);
-    if (isCustomizableToolbar(toolbar)) {
-      if (aRemovePreviousSet)
-        toolbar.removeAttribute('previousset');
+  var paletteItems = gToolbox.getElementsByTagName("toolbarpaletteitem");
+  var paletteItem;
+  while ((paletteItem = paletteItems.item(0)) != null) {
+    var toolbarItem = paletteItem.firstChild;
 
-      for (var k = 0; k < toolbar.childNodes.length; ++k) {
-        var paletteItem = toolbar.childNodes[k];
-        var toolbarItem = paletteItem.firstChild;
+    if (paletteItem.hasAttribute("itemdisabled"))
+      toolbarItem.disabled = true;
 
-        if (toolbarItem && isToolbarItem(toolbarItem)) {
-          var nextSibling = paletteItem.nextSibling;
+    if (paletteItem.hasAttribute("itemcommand"))
+      toolbarItem.setAttribute("command", paletteItem.getAttribute("itemcommand"));
 
-          if (paletteItem.hasAttribute("itemcommand"))
-            toolbarItem.setAttribute("command", paletteItem.getAttribute("itemcommand"));
-          if (paletteItem.hasAttribute("itemobserves"))
-            toolbarItem.setAttribute("observes", paletteItem.getAttribute("itemobserves"));
-
-          paletteItem.removeChild(toolbarItem); 
-          paletteItem.parentNode.removeChild(paletteItem);
-
-          if (nextSibling)
-            toolbar.insertBefore(toolbarItem, nextSibling);
-          else
-            toolbar.appendChild(toolbarItem);
-        }
-      }
-    }
+    paletteItem.parentNode.replaceChild(toolbarItem, paletteItem);
   }
 }
 
-
 /**
  * Creates a wrapper that can be used to contain a toolbaritem and prevent
  * it from receiving UI events.
  */
-function createWrapper(aId)
+function createWrapper(aId, aDocument)
 {
-  var wrapper = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
+  var wrapper = aDocument.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",
                                          "toolbarpaletteitem");
 
   wrapper.id = "wrapper-"+aId;  
@@ -260,7 +230,7 @@ function createWrapper(aId)
  */
 function wrapPaletteItem(aPaletteItem, aCurrentRow, aSpacer)
 {
-  var wrapper = createWrapper(aPaletteItem.id);
+  var wrapper = createWrapper(aPaletteItem.id, document);
 
   wrapper.setAttribute("flex", 1);
   wrapper.setAttribute("align", "center");
@@ -289,13 +259,11 @@ function wrapPaletteItem(aPaletteItem, aCurrentRow, aSpacer)
  */
 function wrapToolbarItem(aToolbarItem)
 {
-  var wrapper = createWrapper(aToolbarItem.id);
-  
-  cleanupItemForToolbar(aToolbarItem, wrapper);
+  var wrapper = createWrapper(aToolbarItem.id, gToolboxDocument);
+
   wrapper.flex = aToolbarItem.flex;
 
-  if (aToolbarItem.parentNode)
-    aToolbarItem.parentNode.removeChild(aToolbarItem);
+  aToolbarItem.parentNode.replaceChild(wrapper, aToolbarItem);
   
   wrapper.appendChild(aToolbarItem);
   
@@ -363,7 +331,7 @@ function buildPalette()
   while (templateNode) {
     // Check if the item is already in a toolbar before adding it to the palette.
     if (!(templateNode.id in currentItems)) {
-      var paletteItem = templateNode.cloneNode(true);
+      var paletteItem = document.importNode(templateNode, true);
 
       if (rowSlot == kRowMax) {
         // Append the old row.
@@ -436,7 +404,7 @@ function fillRowWithFlex(aRow)
 
 /**
  * Makes sure that an item that has been cloned from a template
- * is stripped of all properties that may adversely affect it's
+ * is stripped of any attributes that may adversely affect its
  * appearance in the palette.
  */
 function cleanUpItemForPalette(aItem, aWrapper)
@@ -448,19 +416,22 @@ function cleanUpItemForPalette(aItem, aWrapper)
     aWrapper.setAttribute("title", aItem.getAttribute("title"));
   else if (isSpecialItem(aItem)) {
     var stringBundle = document.getElementById("stringBundle");
-    var title = stringBundle.getString(aItem.id + "Title");
+    // Remove the common "toolbar" prefix to generate the string name.
+    var title = stringBundle.getString(aItem.localName.slice(7) + "Title");
     aWrapper.setAttribute("title", title);
   }
-  
+ 
   // Remove attributes that screw up our appearance.
   aItem.removeAttribute("command");
   aItem.removeAttribute("observes");
-  aItem.removeAttribute("disabled");
   aItem.removeAttribute("type");
-  
-  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
-    aItem.firstChild.removeAttribute("observes");
+  aItem.removeAttribute("width");
 
+  Array.forEach(aWrapper.querySelectorAll("[disabled]"), function(aNode) {
+    aNode.removeAttribute("disabled");
+  });
+
+  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
     // So the throbber doesn't throb in the dialog,
     // cute as that may be...
     aItem.firstChild.removeAttribute("busy");
@@ -469,7 +440,7 @@ function cleanUpItemForPalette(aItem, aWrapper)
 
 /**
  * Makes sure that an item that has been cloned from a template
- * is stripped of all properties that may adversely affect it's
+ * is stripped of all properties that may adversely affect its
  * appearance in the toolbar.  Store critical properties on the 
  * wrapper so they can be put back on the item when we're done.
  */
@@ -483,12 +454,6 @@ function cleanupItemForToolbar(aItem, aWrapper)
     aItem.removeAttribute("command");
   }
 
-  if (aItem.hasAttribute("observes"))
-  {
-    aWrapper.setAttribute("itemobserves", aItem.getAttribute("observes"));
-    aItem.removeAttribute("observes");
-  }
-
   if (aItem.disabled) {
     aWrapper.setAttribute("itemdisabled", "true");
     aItem.disabled = false;
@@ -529,6 +494,62 @@ function setDragActive(aItem, aValue)
   }
 }
 
+function addNewToolbar()
+{
+  var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
+                                .getService(Components.interfaces.nsIPromptService);
+
+  var stringBundle = document.getElementById("stringBundle");
+  var message = stringBundle.getString("enterToolbarName");
+  var title = stringBundle.getString("enterToolbarTitle");
+
+  var name = {};
+
+  // Quitting from the toolbar dialog while the new toolbar prompt is up
+  // can cause things to become unresponsive on the Mac. Until dialog modality
+  // is fixed (395465), disable the "Done" button explicitly.
+  var doneButton = document.getElementById("donebutton");
+  doneButton.disabled = true;
+
+  while (true) {
+
+    if (!promptService.prompt(window, title, message, name, null, {})) {
+      doneButton.disabled = false;
+      return;
+    }
+    
+    if (!name.value) {
+      message = stringBundle.getFormattedString("enterToolbarBlank", [name.value]);
+      continue;
+    }
+
+    var dupeFound = false;
+
+     // Check for an existing toolbar with the same display name
+    for (i = 0; i < gToolbox.childNodes.length; ++i) {
+      var toolbar = gToolbox.childNodes[i];
+      var toolbarName = toolbar.getAttribute("toolbarname");
+
+      if (toolbarName == name.value &&
+          toolbar.getAttribute("type") != "menubar" &&
+          toolbar.nodeName == 'toolbar') {
+        dupeFound = true;
+        break;
+      }
+    }
+
+    if (!dupeFound)
+      break;
+
+    message = stringBundle.getFormattedString("enterToolbarDup", [name.value]);
+  }
+    
+  gToolbox.appendCustomToolbar(name.value, "");
+  
+  toolboxChanged();
+
+  doneButton.disabled = false;
+}
 
 /**
  * Restore the default set of buttons to fixed toolbars,
@@ -536,27 +557,8 @@ function setDragActive(aItem, aValue)
  */
 function restoreDefaultSet()
 {
-  // Restore the defaultset for fixed toolbars.
-  unwrapToolbarItems(false);
-  var toolbar = gToolbox.firstChild;
-  while (toolbar) {
-    if (isCustomizableToolbar(toolbar)) {
-      if (!toolbar.hasAttribute("customindex")) {
-        var defaultSet = toolbar.getAttribute("defaultset");
-        if (defaultSet)
-        {
-          toolbar.currentSet = defaultSet;
-        }
-      }
-    }
-    toolbar = toolbar.nextSibling;
-  }
-
-  // Restore the default icon size (large) and mode (icons and text).
-  updateIconSize(false);
-  document.getElementById("smallicons").checked = false;
-  updateToolbarMode("full");
-  document.getElementById("modelist").value = "full";
+  // Unwrap the items on the toolbar.
+  unwrapToolbarItems();
 
   // Remove all of the customized toolbars.
   var child = gToolbox.lastChild;
@@ -564,41 +566,62 @@ function restoreDefaultSet()
     if (child.hasAttribute("customindex")) {
       var thisChild = child;
       child = child.previousSibling;
+      thisChild.currentSet = "__empty";
       gToolbox.removeChild(thisChild);
     } else {
       child = child.previousSibling;
     }
   }
-  
+
+  // Restore the defaultset for fixed toolbars.
+  var toolbar = gToolbox.firstChild;
+  while (toolbar) {
+    if (isCustomizableToolbar(toolbar)) {
+      var defaultSet = toolbar.getAttribute("defaultset");
+      if (defaultSet)
+        toolbar.currentSet = defaultSet;
+    }
+    toolbar = toolbar.nextSibling;
+  }
+
+  // Restore the default icon size and mode.
+  var defaultMode = gToolbox.getAttribute("defaultmode");
+  var defaultIconsSmall = gToolbox.getAttribute("defaulticonsize") == "small";
+
+  updateIconSize(defaultIconsSmall, true);
+  document.getElementById("smallicons").checked = defaultIconsSmall;
+  updateToolbarMode(defaultMode, true);
+  document.getElementById("modelist").value = defaultMode;
+
   // Now rebuild the palette.
   buildPalette();
 
-  // Now re-wrap the items on the toolbar, but don't clobber previousset.
-  wrapToolbarItems(false);
+  // Now re-wrap the items on the toolbar.
+  wrapToolbarItems();
 
-  repositionDialog();
-  gToolboxChanged = true;
+  toolboxChanged("reset");
 }
 
-function updateIconSize(aUseSmallIcons)
+function updateIconSize(aUseSmallIcons, localDefault)
 {
-  var val = aUseSmallIcons ? "small" : null;
+  gToolboxIconSize = aUseSmallIcons ? "small" : "large";
   
-  setAttribute(gToolbox, "iconsize", val);
+  setAttribute(gToolbox, "iconsize", gToolboxIconSize);
   gToolboxDocument.persist(gToolbox.id, "iconsize");
   
   for (var i = 0; i < gToolbox.childNodes.length; ++i) {
     var toolbar = getToolbarAt(i);
     if (isCustomizableToolbar(toolbar)) {
-      setAttribute(toolbar, "iconsize", val);
+      var toolbarIconSize = (localDefault && toolbar.hasAttribute("defaulticonsize")) ?
+                            toolbar.getAttribute("defaulticonsize") :
+                            gToolboxIconSize;
+      setAttribute(toolbar, "iconsize", toolbarIconSize);
       gToolboxDocument.persist(toolbar.id, "iconsize");
     }
   }
-
-  repositionDialog();
 }
 
-function updateToolbarMode(aModeValue)
+function updateToolbarMode(aModeValue, localDefault)
 {
   setAttribute(gToolbox, "mode", aModeValue);
   gToolboxDocument.persist(gToolbox.id, "mode");
@@ -606,15 +629,16 @@ function updateToolbarMode(aModeValue)
   for (var i = 0; i < gToolbox.childNodes.length; ++i) {
     var toolbar = getToolbarAt(i);
     if (isCustomizableToolbar(toolbar)) {
-      setAttribute(toolbar, "mode", aModeValue);
+      var toolbarMode = (localDefault && toolbar.hasAttribute("defaultmode")) ?
+                        toolbar.getAttribute("defaultmode") :
+                        aModeValue;
+      setAttribute(toolbar, "mode", toolbarMode);
       gToolboxDocument.persist(toolbar.id, "mode");
     }
   }
 
   var iconSizeCheckbox = document.getElementById("smallicons");
   iconSizeCheckbox.disabled = aModeValue == "text";
-
-  repositionDialog();
 }
 
 
@@ -651,7 +675,7 @@ function isToolbarItem(aElt)
 ///////////////////////////////////////////////////////////////////////////
 //// Drag and Drop observers
 
-function onToolbarDragGesture(aEvent)
+function onToolbarDragStart(aEvent)
 {
   nsDragAndDrop.startDrag(aEvent, dragStartObserver);
 }
@@ -661,12 +685,12 @@ function onToolbarDragOver(aEvent)
   nsDragAndDrop.dragOver(aEvent, toolbarDNDObserver);
 }
 
-function onToolbarDragDrop(aEvent)
+function onToolbarDrop(aEvent)
 {
   nsDragAndDrop.drop(aEvent, toolbarDNDObserver);
 }
 
-function onToolbarDragExit(aEvent)
+function onToolbarDragLeave(aEvent)
 {
   if (gCurrentDragOverItem)
     setDragActive(gCurrentDragOverItem, false);
@@ -687,6 +711,7 @@ var dragStartObserver =
     var data = new TransferData();
     data.addDataForFlavour("text/toolbarwrapper-id/"+documentId, item.firstChild.id);
     aXferData.data.push(data);
+    aDragAction.action = Components.interfaces.nsIDragService.DRAGDROP_ACTION_MOVE;
   }
 }
 
@@ -716,6 +741,7 @@ var toolbarDNDObserver =
 
       var direction = window.getComputedStyle(dropTarget.parentNode, null).direction;
       var dropTargetCenter = dropTarget.boxObject.x + (dropTarget.boxObject.width / 2);
+      var dragAfter;
       if (direction == "ltr")
         dragAfter = aEvent.clientX > dropTargetCenter;
       else
@@ -769,7 +795,7 @@ var toolbarDNDObserver =
       if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
         return;
 
-      // Remove the item from it's place in the toolbar.
+      // Remove the item from its place in the toolbar.
       wrapper.parentNode.removeChild(wrapper);
 
       // Determine which toolbar we are dropping on.
@@ -788,7 +814,7 @@ var toolbarDNDObserver =
       // The item has been dragged from the palette
       
       // Create a new wrapper for the item. We don't know the id yet.
-      var wrapper = createWrapper("");
+      var wrapper = createWrapper("", gToolboxDocument);
 
       // Ask the toolbar to clone the item's template, place it inside the wrapper, and insert it in the toolbar.
       var newItem = toolbar.insertItem(draggedItemId, gCurrentDragOverItem == toolbar ? null : gCurrentDragOverItem, wrapper);
@@ -845,8 +871,7 @@ var toolbarDNDObserver =
     
     gCurrentDragOverItem = null;
 
-    repositionDialog();
-    gToolboxChanged = true;
+    toolboxChanged();
   },
   
   _flavourSet: null,
@@ -881,29 +906,19 @@ var paletteDNDObserver =
       if (wrapper.parentNode.lastPermanentChild && wrapper.parentNode.lastPermanentChild.id == wrapper.firstChild.id)
         return;
 
+      var wrapperType = wrapper.getAttribute("type");
+      if (wrapperType != "separator" &&
+          wrapperType != "spacer" &&
+          wrapperType != "spring") {
+        appendPaletteItem(document.importNode(wrapper.firstChild, true));
+        gToolbox.palette.appendChild(wrapper.firstChild);
+      }
+
       // The item was dragged out of the toolbar.
       wrapper.parentNode.removeChild(wrapper);
-      
-      var wrapperType = wrapper.getAttribute("type");
-      if (wrapperType != "separator" && wrapperType != "spacer" && wrapperType != "spring") {
-        // Find the template node in the toolbox palette
-        var templateNode = gToolbox.palette.firstChild;
-        while (templateNode) {
-          if (templateNode.id == itemId)
-            break;
-          templateNode = templateNode.nextSibling;
-        }
-        if (!templateNode)
-          return;
-        
-        // Clone the template and add it to our palette.
-        var paletteItem = templateNode.cloneNode(true);
-        appendPaletteItem(paletteItem);
-      }
     }
     
-    repositionDialog();
-    gToolboxChanged = true;
+    toolboxChanged();
   },
   
   _flavourSet: null,
