@@ -1,6 +1,5 @@
-//@line 38 "/root/tmp/build-mozilla-thunderbird/mozilla/mail/extensions/newsblog/content/feed-subscriptions.js"
+//@line 39 "/root/tmp/build-mozilla-thunderbird/comm-1.9.1/mailnews/extensions/newsblog/content/feed-subscriptions.js"
 
-const MSG_FOLDER_FLAG_TRASH = 0x0100;
 const IPS = Components.interfaces.nsIPromptService;
 const nsIDragService = Components.interfaces.nsIDragService;
 const kRowIndexUndefined = -1;
@@ -16,7 +15,7 @@ var gFeedSubscriptionsWindow = {
     // extract the server argument
     if (window.arguments[0].server)
       this.mRSSServer = window.arguments[0].server;
-    
+
     var docshell = window.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
                         .getInterface(Components.interfaces.nsIWebNavigation)
                         .QueryInterface(Components.interfaces.nsIDocShell);        
@@ -24,13 +23,14 @@ var gFeedSubscriptionsWindow = {
 
     this.mTree = document.getElementById("rssSubscriptionsList");
     this.mBundle = document.getElementById("bundle_newsblog");
-   
+
     this.loadSubscriptions();
     this.mTree.treeBoxObject.view = this.mView;
-    if (this.mView.rowCount > 0) 
-      this.mTree.view.selection.select(0);
+
+    if (window.arguments[0].folder)
+      this.selectFolder(window.arguments[0].folder);
   },
-  
+
   uninit: function ()
   {
     var dismissDialog = true;
@@ -44,7 +44,7 @@ var gFeedSubscriptionsWindow = {
       var newsBlogBundle = document.getElementById("bundle_newsblog");
       dismissDialog = !(promptService.confirmEx(window, newsBlogBundle.getString('subscribe-cancelSubscriptionTitle'), 
                                        newsBlogBundle.getString('subscribe-cancelSubscription'), 
-                                       (IPS.BUTTON_TITLE_YES * IPS.BUTTON_POS_0) + (IPS.BUTTON_TITLE_NO * IPS.BUTTON_POS_1),
+                                       IPS.STD_YES_NO_BUTTONS,
                                        null, null, null, null, { }));    
     }  
     return dismissDialog;
@@ -61,6 +61,9 @@ var gFeedSubscriptionsWindow = {
     
     getItemAtIndex: function (aIndex)
     {
+      if (aIndex < 0 ||
+          aIndex >= gFeedSubscriptionsWindow.mFeedContainers.length)
+        return null;
       return gFeedSubscriptionsWindow.mFeedContainers[aIndex];
     },
 
@@ -107,10 +110,7 @@ var gFeedSubscriptionsWindow = {
     getCellText: function (aIndex, aColumn)
     {
       var item = this.getItemAtIndex(aIndex);
-      if (!item) 
-        return "";
-      else if (aColumn.id == "folderNameCol")
-        return item.name;
+      return (item && aColumn.id == "folderNameCol") ? item.name : "";
     },
 
     _selection: null, 
@@ -297,6 +297,10 @@ var gFeedSubscriptionsWindow = {
     { 
       return false; 
     },
+    isSelectable: function (aIndex, aColumn) 
+    { 
+      return false; 
+    },
     setCellValue: function (aIndex, aColumn, aValue) {},    
     setCellText: function (aIndex, aColumn, aValue) {},    
     performAction: function (aAction) {},  
@@ -314,24 +318,15 @@ var gFeedSubscriptionsWindow = {
                           container: true };
 
     // if a feed has any sub folders, we should add them to the list of children
-    if (aFolder.hasSubFolders)
+    var folderEnumerator = aFolder.subFolders;
+
+    while (folderEnumerator.hasMoreElements())
     {
-      var folderEnumerator = aFolder.GetSubFolders();
-      var done = false;
-
-      while (!done) 
-      {
-        var folder = folderEnumerator.currentItem().QueryInterface(Components.interfaces.nsIMsgFolder);
-        folderObject.children.push(this.makeFolderObject(folder, aCurrentLevel + 1));
-
-        try {
-          folderEnumerator.next();
-        } 
-        catch (ex)
-        {
-          done = true;
-        }        
-      }
+      var folder = folderEnumerator.getNext();
+      if ((folder instanceof Components.interfaces.nsIMsgFolder) &&
+          !folder.getFlag(Components.interfaces.nsMsgFolderFlags.Virtual))
+        folderObject.children
+                    .push(this.makeFolderObject(folder, aCurrentLevel + 1));
     }
 
     var feeds = this.getFeedsInFolder(aFolder);
@@ -354,9 +349,10 @@ var gFeedSubscriptionsWindow = {
     var feeds = new Array();
     try
     {
-      var msgdb = aFolder.QueryInterface(Components.interfaces.nsIMsgFolder).getMsgDatabase(null);
+      var msgdb = aFolder.QueryInterface(Components.interfaces.nsIMsgFolder)
+                         .msgDatabase;
       var folderInfo = msgdb.dBFolderInfo;
-      var feedurls = folderInfo.getCharPtrProperty("feedUrl");
+      var feedurls = folderInfo.getCharProperty("feedUrl");
       var feedUrlArray = feedurls.split("|");
       for (url in feedUrlArray)
       {
@@ -389,34 +385,78 @@ var gFeedSubscriptionsWindow = {
     var numFolders = 0;
     this.mFeedContainers = [];
 
-    if (this.mRSSServer.rootFolder.hasSubFolders)
+    var folderEnumerator = this.mRSSServer.rootFolder.subFolders;
+
+    while (folderEnumerator.hasMoreElements())
     {
-      var folderEnumerator = this.mRSSServer.rootFolder.GetSubFolders();
-      var done = false;
-
-      while (!done) 
+      var folder = folderEnumerator.getNext();
+      if ((folder instanceof Components.interfaces.nsIMsgFolder) &&
+          !folder.getFlag(Components.interfaces.nsMsgFolderFlags.Trash) &&
+          !folder.getFlag(Components.interfaces.nsMsgFolderFlags.Virtual))
       {
-        var folder = folderEnumerator.currentItem().QueryInterface(Components.interfaces.nsIMsgFolder);
-        if (folder && !folder.getFlag(MSG_FOLDER_FLAG_TRASH)) 
-        {
-          this.mFeedContainers.push(this.makeFolderObject(folder, 0));
-          numFolders++;
-        }
-
-        try {
-          folderEnumerator.next();
-        } 
-        catch (ex)
-        {
-          done = true;
-        }        
+        this.mFeedContainers.push(this.makeFolderObject(folder, 0));
+        numFolders++;
       }
     }
     this.mView.mRowCount = numFolders;
 
     gFeedSubscriptionsWindow.mTree.focus();
   },
+
+  selectFolder: function(aFolder)
+  {
+    if (aFolder.isServer)
+      return;
+
+    var folderURI = aFolder.QueryInterface(Components.interfaces.nsIRDFResource)
+                           .Value;
+
+    function containsFolder(aItem)
+    {
+      var items = aItem ? aItem.children : this.mFeedContainers;
+      for (var i = 0; i < items.length; i++) {
+        if (items[i].url == folderURI ||
+            item.container && containsFolder(items[i]))
+          return true;
+      }
+      return false;
+    }
+
+    for (var index = 0; index < this.mView.rowCount; index++)
+    {
+      var item = this.mView.getItemAtIndex(index);
+      if (item.url == folderURI || containsFolder(item))
+      {
+        if (!item.open)
+          this.mView.toggleOpenState(index);
+        if (item.url == folderURI) {
+          // we found the actual folder - not an ancestor
+          this.mTree.view.selection.select(index);
+          this.mTree.boxObject.ensureRowIsVisible(index);
+          break;
+        }
+      }
+    }
+  },
   
+  selectFeed: function(aFeed)
+  {
+    this.selectFolder(aFeed.folder);
+
+    var seln = this.mTree.view.selection;
+    var item = this.mView.getItemAtIndex(seln.currentIndex);
+    if (item) {
+      for (var i = 0; i < item.children.length; i++) {
+        if (item.children[i].url == aFeed.url) {
+          var index = seln.currentIndex + i + 1;
+          this.mTree.view.selection.select(index);
+          this.mTree.boxObject.ensureRowIsVisible(index);
+          break;
+        }
+      }
+    }
+  },
+
   updateFeedData: function (aItem)
   {
     var ids = ['nameLabel', 'nameValue', 'locationLabel', 'locationValue'];
@@ -428,24 +468,22 @@ var gFeedSubscriptionsWindow = {
     }
     else 
     {
-      var noneSelected = this.mBundle.getString("subscribe-noFeedSelected");
+      var noneSelected = this.mBundle.getString('subscribe-noFeedIsSelected');
       document.getElementById('nameValue').value = noneSelected;
       document.getElementById('locationValue').value = "";
     }
 
-    for (i = 0; i < ids.length; ++i)
+    for (var i = 0; i < ids.length; ++i)
       document.getElementById(ids[i]).disabled = !aItem || aItem.container;
   },
-  
+ 
   onKeyPress: function(aEvent)
-  { 
-    if (aEvent.keyCode == aEvent.DOM_VK_ENTER || aEvent.keyCode == aEvent.DOM_VK_RETURN)
-    {
-      var seln = this.mTree.view.selection;
-      item = this.mView.getItemAtIndex(seln.currentIndex);
-      if (item && !item.container)
-        this.editFeed();
-     }
+  {
+    if (aEvent.keyCode == aEvent.DOM_VK_ENTER ||
+        aEvent.keyCode == aEvent.DOM_VK_RETURN)
+      this.editFeed();
+    else if (aEvent.keyCode == aEvent.DOM_VK_DELETE)
+      this.removeFeed();
   },
 
   onSelect: function () 
@@ -453,69 +491,31 @@ var gFeedSubscriptionsWindow = {
     var properties, item;
     var seln = this.mTree.view.selection;
     item = this.mView.getItemAtIndex(seln.currentIndex);
-      
     this.updateFeedData(item);
-        
     document.getElementById("removeFeed").disabled = !item || item.container;
     document.getElementById("editFeed").disabled = !item || item.container;
   },
   
-  removeFeed: function () 
+  removeFeed: function ()
   { 
     var seln = this.mView.selection;
-    if (seln.count != 1) return;
+    if (seln.count != 1)
+      return;
 
     var itemToRemove = this.mView.getItemAtIndex(seln.currentIndex);
 
-    if (!itemToRemove)
+    if (!itemToRemove || itemToRemove.container)
       return;
 
     // ask the user if he really wants to unsubscribe from the feed
     var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(IPS);
-    var abortRemoval = promptService.confirmEx(window, this.mBundle.getString('subsribe-confirmFeedDeletionTitle'), 
-                                                  this.mBundle.getFormattedString('subsribe-confirmFeedDeletion', [itemToRemove.name], 1), 
-                                                  (IPS.BUTTON_TITLE_YES * IPS.BUTTON_POS_0) + (IPS.BUTTON_TITLE_NO * IPS.BUTTON_POS_1),
-                                                  null, null, null, null, { });
+    var abortRemoval = promptService.confirmEx(window, this.mBundle.getString('subscribe-confirmFeedDeletionTitle'),
+                                               this.mBundle.getFormattedString('subscribe-confirmFeedDeletion', [itemToRemove.name], 1),
+                                               IPS.STD_YES_NO_BUTTONS, null, null, null, null, { });
     if (abortRemoval)
       return;
 
-    var resource = rdf.GetResource(itemToRemove.url);
-    var feed = new Feed(resource, this.mRSSServer);
-    var ds = getSubscriptionsDS(this.mRSSServer);
-
-    if (feed && ds)
-    {
-      // remove the feed from the subscriptions ds
-      var feeds = getSubscriptionsList(this.mRSSServer);
-      var index = feeds.IndexOf(resource);
-      if (index != kRowIndexUndefined)
-        feeds.RemoveElementAt(index, false);
-
-      // remove the feed property string from the folder data base
-      var currentFolder = ds.GetTarget(resource, FZ_DESTFOLDER, true);
-      if (currentFolder) 
-      {
-        var currentFolderURI = currentFolder.QueryInterface(Components.interfaces.nsIRDFResource).Value;
-        currentFolder = rdf.GetResource(currentFolderURI).QueryInterface(Components.interfaces.nsIMsgFolder);
-    
-        var feedUrl = ds.GetTarget(resource, DC_IDENTIFIER, true);    
-        ds.Unassert(resource, DC_IDENTIFIER, feedUrl, true);
-
-        feedUrl = feedUrl ? feedUrl.QueryInterface(Components.interfaces.nsIRDFLiteral).Value : "";
-
-        updateFolderFeedUrl(currentFolder, feedUrl, true); // remove the old url
-      }
-
-      // Remove all assertions about the feed from the subscriptions database.
-      removeAssertions(ds, resource);
-      ds.QueryInterface(Components.interfaces.nsIRDFRemoteDataSource).Flush(); // flush any changes
-
-      // Remove all assertions about items in the feed from the items database.
-      var itemds = getItemsDS(this.mRSSServer);
-      feed.invalidateItems();
-      feed.removeInvalidItems();
-      itemds.QueryInterface(Components.interfaces.nsIRDFRemoteDataSource).Flush(); // flush any changes
-    }
+    deleteFeed(rdf.GetResource(itemToRemove.url), this.mRSSServer);
 
     // Now that we have removed the feed from the datasource, it is time to update our
     // view layer. Start by removing the child from its parent folder object
@@ -526,9 +526,9 @@ var gFeedSubscriptionsWindow = {
     // Cheat and look at the feed url property to see if anyone else is still using the feed...
     // you could also accomplish this by looking at some properties in the data source...
 
-//    var msgdb = currentFolder.QueryInterface(Components.interfaces.nsIMsgFolder).getMsgDatabase(null);
+//    var msgdb = currentFolder.QueryInterface(Components.interfaces.nsIMsgFolder).msgDatabase;
 //   var folderInfo = msgdb.dBFolderInfo;
-//    var oldFeedUrl = folderInfo.getCharPtrProperty("feedUrl");
+//    var oldFeedUrl = folderInfo.getCharProperty("feedUrl");
 
 //    if (!oldFeedUrl) // no more feeds pointing to the folder?
 //    {
@@ -544,15 +544,27 @@ var gFeedSubscriptionsWindow = {
   addFeed: function(aFeedLocation, aRootFolderURI)
   {
     var userAddedFeed = false; 
-    var defaultQuickMode = this.mRSSServer.getBoolAttribute('quickMode');
+    var defaultQuickMode = this.mRSSServer.getBoolValue('quickMode');
     var feedProperties = { feedName: "", feedLocation: aFeedLocation, 
                            serverURI: this.mRSSServer.serverURI, 
                            serverPrettyName: this.mRSSServer.prettyName,  
-                           folderURI: aRootFolderURI, 
-                           quickMode: this.mRSSServer.getBoolAttribute('quickMode'), 
+                           quickMode: this.mRSSServer.getBoolValue('quickMode'),
                            newFeed: true,
                            result: userAddedFeed};
 
+    // unless another folder is specified, default to currently selected
+    if (aRootFolderURI) {
+      feedProperties.folderURI = aRootFolderURI;
+    } else {
+      var index = this.mTree.view.selection.currentIndex;
+      var item = this.mView.getItemAtIndex(index);
+      if (item) {
+        if (!item.container)
+          item = this.mView.getItemAtIndex(this.mView.getParentIndex(index));
+        feedProperties.folderURI = item.url;
+      }
+    }
+
     feedProperties = openFeedEditor(feedProperties);
 
     // if the user hit cancel, exit without doing anything
@@ -569,13 +581,14 @@ var gFeedSubscriptionsWindow = {
       promptService.alert(window, null, this.mBundle.getString("subscribe-feedAlreadySubscribed"));            
       return;
     }
-  
+
     var feed = this.storeFeed(feedProperties);
-    if(!feed)
+    if (!feed)
       return;
 
     // Now validate and start downloadng the feed....
-    updateStatusItem('statusText', document.getElementById("bundle_newsblog").getString('subscribe-validating'));
+    updateStatusItem('statusText', document.getElementById('bundle_newsblog')
+                                           .getString('subscribe-validating-feed'));
     updateStatusItem('progressMeter', 0);
     document.getElementById('addFeed').setAttribute('disabled', 'true');
     feed.download(true, this.mFeedDownloadCallback);
@@ -585,7 +598,7 @@ var gFeedSubscriptionsWindow = {
   storeFeed: function(feedProperties)
   {
     var itemResource = rdf.GetResource(feedProperties.feedLocation);
-    feed = new Feed(itemResource, this.mRSSServer);
+    var feed = new Feed(itemResource, this.mRSSServer);
 
     // if the user specified a specific folder to add the feed too, then set it here
     if (feedProperties.folderURI)
@@ -690,7 +703,7 @@ var gFeedSubscriptionsWindow = {
     
     currentItem.level = newParentItem.level + 1;
     newParentItem.children.push(currentItem);
-    var indexOfNewItem = aNewParentIndex + newParentItem.children.length;;
+    var indexOfNewItem = aNewParentIndex + newParentItem.children.length;
 
     if (!newParentItem.open) // force open the container
       this.mView.toggleOpenState(aNewParentIndex);
@@ -716,24 +729,17 @@ var gFeedSubscriptionsWindow = {
     if (!item || item.container)
       return;
 
-    var transfer = Components.classes["@mozilla.org/widget/transferable;1"].createInstance(Components.interfaces.nsITransferable); 
-    var transArray = Components.classes["@mozilla.org/supports-array;1"].createInstance(Components.interfaces.nsISupportsArray);
-    var dragData = Components.classes["@mozilla.org/supports-string;1"].createInstance(Components.interfaces.nsISupportsString);
-
-    transfer.addDataFlavor("text/x-moz-feed-index"); // i made this flavor type up
-    dragData.data = seln.currentIndex.toString();
-
-    transfer.setTransferData ( "text/x-moz-feed-index", dragData, seln.currentIndex.toString() * 2 );  // doublebyte byte data
-    transArray.AppendElement(transfer.QueryInterface(Components.interfaces.nsISupports));
-
-    var dragService = Components.classes["@mozilla.org/widget/dragservice;1"].getService().QueryInterface(nsIDragService);
-    dragService.invokeDragSession ( aEvent.target, transArray, null, nsIDragService.DRAGDROP_ACTION_MOVE);
+    aEvent.dataTransfer.setData("text/x-moz-feed-index", seln.currentIndex.toString());
+    aEvent.dataTransfer.effectAllowed = "move";
   },
 
   mFeedDownloadCallback:
   {
     downloaded: function(feed, aErrorCode)
     {
+      var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
+                                    .getService(Components.interfaces.nsIPromptService);
+
       // feed is null if our attempt to parse the feed failed
       if (aErrorCode == kNewsBlogSuccess)
       {
@@ -749,11 +755,17 @@ var gFeedSubscriptionsWindow = {
 
         // now add the feed to our view
         refreshSubscriptionView();
-      } 
+
+        gFeedSubscriptionsWindow.selectFeed(feed);
+      }
       else if (aErrorCode == kNewsBlogInvalidFeed) //  the feed was bad...
-        window.alert(gFeedSubscriptionsWindow.mBundle.getFormattedString('newsblog-invalidFeed', [feed.url]));
-      else if (aErrorCode == kNewsBlogRequestFailure) 
-        window.alert(gFeedSubscriptionsWindow.mBundle.getFormattedString('newsblog-networkError', [feed.url]));
+        promptService.alert(null,
+          gFeedSubscriptionsWindow.mBundle.getString('newsblog-feedNotValidTitle'),
+          gFeedSubscriptionsWindow.mBundle.getFormattedString('newsblog-feedNotValid', [feed.url]));
+      else if (aErrorCode == kNewsBlogRequestFailure)
+        promptService.alert(null,
+          gFeedSubscriptionsWindow.mBundle.getString('newsblog-networkErrorTitle'),
+          gFeedSubscriptionsWindow.mBundle.getFormattedString('newsblog-networkError', [feed.url]));
 
       // re-enable the add button now that we are done subscribing
       document.getElementById('addFeed').removeAttribute('disabled');
@@ -766,8 +778,8 @@ var gFeedSubscriptionsWindow = {
     // aCurrentFeedItems is an integer corresponding to how many feed items have been downloaded so far
     // aMaxFeedItems is an integer corresponding to the total number of feed items to download
     onFeedItemStored: function (feed, aCurrentFeedItems, aMaxFeedItems)
-    { 
-      updateStatusItem('statusText', gFeedSubscriptionsWindow.mBundle.getFormattedString("subscribe-fetchingFeedItems", 
+    {
+      updateStatusItem('statusText', gFeedSubscriptionsWindow.mBundle.getFormattedString('subscribe-gettingFeedItems',
                                                                                          [aCurrentFeedItems, aMaxFeedItems]));
       this.onProgress(feed, aCurrentFeedItems, aMaxFeedItems);
     },
@@ -775,7 +787,7 @@ var gFeedSubscriptionsWindow = {
     onProgress: function(feed, aProgress, aProgressMax)
     {
       updateStatusItem('progressMeter', (aProgress * 100) / aProgressMax);
-    },
+    }
   },
 
   exportOPML: function()
@@ -788,11 +800,16 @@ var gFeedSubscriptionsWindow = {
 
       this.generatePPSpace(opmlRoot,"  ");
 
+      var brandBundle = document.getElementById("bundle_brand");
+
       // Make the <head> element
       var head = opmlDoc.createElement("head");
       this.generatePPSpace(head, "    ");
+      var titleText = this.mBundle.getFormattedString(
+                        "subscribe-OPMLExportFileDialogTitle",
+                        [brandBundle.getString("brandShortName")], 1);
       var title = opmlDoc.createElement("title");
-      title.appendChild(opmlDoc.createTextNode(this.mBundle.getString("subscribe-OPMLExportFileTitle")));
+      title.appendChild(opmlDoc.createTextNode(titleText));
       head.appendChild(title);
       this.generatePPSpace(head, "    ");
       var dt = opmlDoc.createElement("dateCreated");
@@ -812,8 +829,11 @@ var gFeedSubscriptionsWindow = {
       this.generatePPSpace(opmlRoot, "");
 
       var serial=new XMLSerializer();
+      var omplFileName = this.mBundle.getFormattedString(
+                           "subscribe-OPMLExportDefaultFileName",
+                           [brandBundle.getString("brandShortName")], 1);
       var rv = pickSaveAs(this.mBundle.getString("subscribe-OPMLExportTitle"),'$all',
-                          this.mBundle.getString("subscribe-OPMLExportFileName"));
+                          omplFileName);
       if(rv.reason == PICK_CANCEL)
         return;
       else if(rv)
@@ -834,21 +854,22 @@ var gFeedSubscriptionsWindow = {
   
   generateOutline: function(baseFolder, parent, indentLevel)
   {
-    var folderEnumerator = baseFolder.GetSubFolders();
-    var done = false;
+    var folderEnumerator = baseFolder.subFolders;
 
     // pretty printing
     var indentString = "";
     for(i = 0; i < indentLevel; i++)
       indentString = indentString + " ";
  
-    while (!done) 
+    while (folderEnumerator.hasMoreElements())
     {
-      var folder = folderEnumerator.currentItem().QueryInterface(Components.interfaces.nsIMsgFolder);
-      if (folder && !folder.getFlag(MSG_FOLDER_FLAG_TRASH)) 
+      var folder = folderEnumerator.getNext();
+      if ((folder instanceof Components.interfaces.nsIMsgFolder) &&
+          !folder.getFlag(Components.interfaces.nsMsgFolderFlags.Trash) &&
+          !folder.getFlag(Components.interfaces.nsMsgFolderFlags.Virtual))
       {
         var outline;
-        if(folder.hasSubFolders)
+        if (folder.hasSubFolders)
         {
           // Make a mostly empty outline element
           outline = parent.ownerDocument.createElement("outline");
@@ -870,14 +891,6 @@ var gFeedSubscriptionsWindow = {
           }
         }
       }
-      
-      try {
-        folderEnumerator.next();
-      } 
-      catch (ex)
-      {
-        done = true;
-      }
     }
   },
   
@@ -909,89 +922,86 @@ var gFeedSubscriptionsWindow = {
       var parser = new DOMParser();
       opmlDom = parser.parseFromStream(stream, null, stream.available(), 'application/xml');
     }catch(e){
-      return promptService.alert(window, null, this.mBundle.getString("subscribe-errorOpeningFile"));
+      promptService.alert(window, null, this.mBundle.getString("subscribe-errorOpeningFile"));
+      return;
     }finally{
       stream.close();
     }
 
     // return if the user didn't give us an OPML file
     if(!opmlDom || !(opmlDom.documentElement.tagName == "opml"))
-      return promptService.alert(window, null, this.mBundle.getFormattedString("subscribe-errorInvalidOPMLFile", [rv.file.leafName]));
+    {
+      promptService.alert(window, null, this.mBundle.getFormattedString("subscribe-errorInvalidOPMLFile", [rv.file.leafName]));
+      return;
+    }
 
     var outlines = opmlDom.getElementsByTagName("body")[0].getElementsByTagName("outline");
     var feedsAdded = false;
  
     for (var index = 0; index < outlines.length; index++)
-    {
-      var outline = outlines[index];
-     
-      // XXX only dealing with flat OPML files for now. 
-      // We still need to add support for grouped files.      
-      if(outline.hasAttribute("xmlUrl") || outline.hasAttribute("url"))
-      {
-        var userAddedFeed = false; 
-        var newFeedUrl = outline.getAttribute("xmlUrl") || outline.getAttribute("url")
-        var defaultQuickMode = this.mRSSServer.getBoolAttribute('quickMode');
-        var feedProperties = { feedName: this.findOutlineTitle(outline),
-                               feedLocation: newFeedUrl, 
-                               serverURI: this.mRSSServer.serverURI, 
-                               serverPrettyName: this.mRSSServer.prettyName,  
-                               folderURI: "", 
-                               quickMode: this.mRSSServer.getBoolAttribute('quickMode')};
-
-        debug("importing feed: "+ feedProperties.feedName);
-       
-        // Silently skip feeds that are already subscribed to. 
-        if (!feedAlreadyExists(feedProperties.feedLocation, this.mRSSServer))
-        {
-          var feed = this.storeFeed(feedProperties);
-       
-          if(feed)
-          {
-            feed.title = feedProperties.feedName;
-            if(outline.hasAttribute("htmlUrl"))
-              feed.link = outline.getAttribute("htmlUrl");
-
-            feed.createFolder();
-            updateFolderFeedUrl(feed.folder, feed.url, false);
-            
-            // add feed adds the feed we have validated and downloaded to our datasource
-            // it also flushes the subscription datasource
-            addFeed(feed.url, feed.name, feed.folder); 
-            feedsAdded = true;
-          }
-        }
-      }
-    }
+      if (this.importOutline(outlines[index]) && !feedsAdded)
+        feedsAdded = true;
 
     if (!outlines.length || !feedsAdded)
-      return promptService.alert(window, null, this.mBundle.getFormattedString("subscribe-errorInvalidOPMLFile", [rv.file.leafName]));
+    {
+      promptService.alert(window, null, this.mBundle.getFormattedString("subscribe-errorInvalidOPMLFile", [rv.file.leafName]));
+      return;
+    }
 
-    //add the new feeds to our view
+    // add the new feeds to our view
     refreshSubscriptionView();
   },
-  
-  findOutlineTitle: function(anOutline)
+
+  importOutline: function(aOutline)
   {
-    var outlineTitle;
+    // XXX only dealing with flat OPML files for now.
+    // We still need to add support for grouped files.
+    var newFeedUrl = aOutline.getAttribute("xmlUrl") ||
+                     aOutline.getAttribute("url");
 
-    if (anOutline.hasAttribute("text"))
-      outlineTitle = anOutline.getAttribute("text");
-    else if (anOutline.hasAttribute("title"))
-      outlineTitle = anOutline.getAttribute("title");
-    else if (anOutline.hasAttribute("xmlUrl"))
-      outlineTitle = anOutline.getAttribute("xmlUrl");
+    // Silently skip feeds that are already subscribed to.
+    if (newFeedUrl && !feedAlreadyExists(newFeedUrl, this.mRSSServer))
+    {
+      var feedName = aOutline.getAttribute("text") ||
+                     aOutline.getAttribute("title") ||
+                     aOutline.getAttribute("xmlUrl");
 
-    return outlineTitle;
+      var defaultQuickMode = this.mRSSServer.getBoolValue('quickMode');
+      var feedProperties = { feedName: feedName,
+                             feedLocation: newFeedUrl,
+                             serverURI: this.mRSSServer.serverURI,
+                             serverPrettyName: this.mRSSServer.prettyName,
+                             folderURI: "",
+                             quickMode: defaultQuickMode};
 
-  },
+      debug("importing feed: "+ feedProperties.feedName);
+ 
+      var feed = this.storeFeed(feedProperties);
+      if (feed)
+      {
+        feed.title = feedProperties.feedName;
+        if (aOutline.hasAttribute("htmlUrl"))
+          feed.link = aOutline.getAttribute("htmlUrl");
 
+        feed.createFolder();
+        updateFolderFeedUrl(feed.folder, feed.url, false);
+ 
+        // addFeed adds the feed we have validated and downloaded to
+        // our datasource, it also flushes the subscription datasource.
+        addFeed(feed.url, feed.name, feed.folder);
+        return true;
+      }
+    }
+    return false;
+  }
 };
 
 // opens the feed properties dialog
 function openFeedEditor(aFeedProperties)
 {
-  window.openDialog('chrome://messenger-newsblog/content/feed-properties.xul', 'feedproperties', 'modal,titlebar,chrome,center', aFeedProperties);
+  window.openDialog('chrome://messenger-newsblog/content/feed-properties.xul',
+                    'feedproperties', 'modal,titlebar,chrome,centerscreen',
+                    aFeedProperties);
   return aFeedProperties;
 } 
 
