@@ -1,4 +1,4 @@
-//@line 39 "/root/tmp/build-mozilla-thunderbird/mozilla/mail/components/preferences/connection.js"
+//@line 39 "/root/tmp/build-mozilla-thunderbird/comm-1.9.1/mail/components/preferences/connection.js"
 
 var gConnectionsDialog = {
   beforeAccept: function ()
@@ -29,13 +29,22 @@ var gConnectionsDialog = {
       }
     }
 
+    var noProxiesPref = document.getElementById("network.proxy.no_proxies_on");
+    noProxiesPref.value = noProxiesPref.value.replace(/[;]/g,',');
+
     return true;
   },
-  
+
+  checkForSystemProxy: function ()
+  {
+    if ("@mozilla.org/system-proxy-settings;1" in Components.classes)
+      document.getElementById("systemPref").removeAttribute("hidden");
+  },
+
   proxyTypeChanged: function ()
   {
     var proxyTypePref = document.getElementById("network.proxy.type");
-    
+
     // Update http
     var httpProxyURLPref = document.getElementById("network.proxy.http");
     httpProxyURLPref.disabled = proxyTypePref.value != 1;
@@ -47,23 +56,44 @@ var gConnectionsDialog = {
 
     var shareProxiesPref = document.getElementById("network.proxy.share_proxy_settings");
     shareProxiesPref.disabled = proxyTypePref.value != 1;
-    
+
     var noProxiesPref = document.getElementById("network.proxy.no_proxies_on");
     noProxiesPref.disabled = proxyTypePref.value != 1;
-    
+
     var autoconfigURLPref = document.getElementById("network.proxy.autoconfig_url");
     autoconfigURLPref.disabled = proxyTypePref.value != 2;
-    
-    var disableReloadPref = document.getElementById("pref.advanced.proxies.disable_button.reload");
-    disableReloadPref.disabled = proxyTypePref.value != 2;
+
+    this.updateReloadButton();
   },
-  
+
+  updateReloadButton: function ()
+  {
+    // Disable the "Reload PAC" button if the selected proxy type is not PAC or
+    // if the current value of the PAC textbox does not match the value stored
+    // in prefs.  Likewise, disable the reload button if PAC is not configured
+    // in prefs.
+
+    var typedURL = document.getElementById("networkProxyAutoconfigURL").value;
+    var proxyTypeCur = document.getElementById("network.proxy.type").value;
+
+    var prefs =
+        Components.classes["@mozilla.org/preferences-service;1"].
+        getService(Components.interfaces.nsIPrefBranch);
+    var pacURL = prefs.getCharPref("network.proxy.autoconfig_url");
+    var proxyType = prefs.getIntPref("network.proxy.type");
+
+    var disableReloadPref =
+        document.getElementById("pref.advanced.proxies.disable_button.reload");
+    disableReloadPref.disabled =
+        (proxyTypeCur != 2 || proxyType != 2 || typedURL != pacURL);
+  },
+
   readProxyType: function ()
   {
     this.proxyTypeChanged();
     return undefined;
   },
-  
+
   updateProtocolPrefs: function ()
   {
     var proxyTypePref = document.getElementById("network.proxy.type");
@@ -72,7 +102,7 @@ var gConnectionsDialog = {
     for (var i = 0; i < proxyPrefs.length; ++i) {
       var proxyServerURLPref = document.getElementById("network.proxy." + proxyPrefs[i]);
       var proxyPortPref = document.getElementById("network.proxy." + proxyPrefs[i] + "_port");
-      
+
       // Restore previous per-proxy custom settings, if present. 
       if (!shareProxiesPref.value) {
         var backupServerURLPref = document.getElementById("network.proxy.backup." + proxyPrefs[i]);
@@ -94,10 +124,10 @@ var gConnectionsDialog = {
     }
     var socksVersionPref = document.getElementById("network.proxy.socks_version");
     socksVersionPref.disabled = proxyTypePref.value != 1 || shareProxiesPref.value;
-    
+
     return undefined;
   },
-  
+
   readProxyProtocolPref: function (aProtocol, aIsPort)
   {
     var shareProxiesPref = document.getElementById("network.proxy.share_proxy_settings");
@@ -105,19 +135,17 @@ var gConnectionsDialog = {
       var pref = document.getElementById("network.proxy.http" + (aIsPort ? "_port" : ""));    
       return pref.value;
     }
-    
+
     var backupPref = document.getElementById("network.proxy.backup." + aProtocol + (aIsPort ? "_port" : ""));
     return backupPref.hasUserValue ? backupPref.value : undefined;
   },
 
   reloadPAC: function ()
   {
-    var autoURL = document.getElementById("networkProxyAutoconfigURL");
-    var pps = Components.classes["@mozilla.org/network/protocol-proxy-service;1"]
-                        .getService(Components.interfaces.nsPIProtocolProxyService);
-    pps.configureFromPAC(autoURL.value);
+    Components.classes["@mozilla.org/network/protocol-proxy-service;1"].
+        getService().reloadPAC();
   },
-  
+
   doAutoconfigURLFixup: function ()
   {
     var autoURL = document.getElementById("networkProxyAutoconfigURL");
@@ -128,7 +156,7 @@ var gConnectionsDialog = {
       autoURLPref.value = autoURL.value = URIFixup.createFixupURI(autoURL.value, 0).spec;
     } catch(ex) {}
   },
-  
+
   readHTTPProxyServer: function ()
   {
     var shareProxiesPref = document.getElementById("network.proxy.share_proxy_settings");
@@ -136,12 +164,12 @@ var gConnectionsDialog = {
       this.updateProtocolPrefs();
     return undefined;
   },
-  
+
   readHTTPProxyPort: function ()
   {
     var shareProxiesPref = document.getElementById("network.proxy.share_proxy_settings");
     if (shareProxiesPref.value)
       this.updateProtocolPrefs();
     return undefined;
-  },
+  }
 };
