@@ -1,67 +1,71 @@
-//@line 37 "/root/tmp/build-mozilla-thunderbird/mozilla/toolkit/mozapps/extensions/content/update.js"
+//@line 38 "/root/tmp/build-mozilla-thunderbird/comm-1.9.1/mozilla/toolkit/mozapps/extensions/content/update.js"
 
-//
-// This UI can be opened from the following places, and in the following modes:
-//
-// - from the Version Compatibility Checker at startup
-//    as the application starts a check is done to see if the application being
-//    started is the same version that was started last time. If it isn't, a
-//    list of UpdateItems that are incompatible with the verison being 
-//    started is generated and this UI opened with that list. This UI then
-//    offers to check for updates to those UpdateItems that are compatible
-//    with the version of the application being started. 
-//    
-//    In this mode, the wizard is opened to panel 'mismatch'. 
+// This UI is only opened from the Extension Manager when the app is upgraded.
 
+const nsIExtensionManager = Components.interfaces.nsIExtensionManager;
 const nsIUpdateItem = Components.interfaces.nsIUpdateItem;
 const nsIAUCL = Components.interfaces.nsIAddonUpdateCheckListener;
 
 const PREF_UPDATE_EXTENSIONS_ENABLED            = "extensions.update.enabled";
-const PREF_UPDATE_EXTENSIONS_AUTOUPDATEENABLED  = "extensions.update.autoUpdateEnabled";
-
-var gShowMismatch = null;
-var gUpdateTypes  = null;
+const PREF_XPINSTALL_ENABLED                    = "xpinstall.enabled";
 
 var gUpdateWizard = {
-  // The items to check for updates for (e.g. an extension, some subset of extensions, 
-  // all extensions, a list of compatible extensions, etc...)
+  // When synchronizing app compatibility info this contains all installed
+  // add-ons. When checking for compatible versions this contains only
+  // incompatible add-ons.
   items: [],
+  // Contains a list of items that were disabled prior to the application
+  // upgrade.
+  inactiveItemIDs: [],
   // The items that we found updates available for
   itemsToUpdate: [],
-  // The items that we successfully installed updates for
-  updatedCount: 0,
   shouldSuggestAutoChecking: false,
   shouldAutoCheck: false,
-  
-  remainingExtensionUpdateCount: 0,
-  
-  succeeded: true,
-  
+  xpinstallEnabled: false,
+  xpinstallLocked: false,
+
   init: function ()
   {
     var em = Components.classes["@mozilla.org/extensions/manager;1"]
-                        .getService(Components.interfaces.nsIExtensionManager);
+                        .getService(nsIExtensionManager);
     // Retrieve all items in order to sync their app compatibility information
-    this.items = em.getItemList(nsIUpdateItem.TYPE_ADDON, { });
-    var pref = 
+    this.items = em.getItemList(nsIUpdateItem.TYPE_ANY, { });
+    this.inactiveItemIDs = window.arguments[0];
+    var pref =
         Components.classes["@mozilla.org/preferences-service;1"].
         getService(Components.interfaces.nsIPrefBranch);
-    this.shouldSuggestAutoChecking = 
-      gShowMismatch && 
-      !pref.getBoolPref(PREF_UPDATE_EXTENSIONS_AUTOUPDATEENABLED);
 
-    document.documentElement.currentPage = 
-      document.getElementById("versioninfo");
+    try {
+      this.shouldSuggestAutoChecking =
+        !pref.getBoolPref(PREF_UPDATE_EXTENSIONS_ENABLED);
+    }
+    catch (e) {
+    }
+
+    try {
+      this.xpinstallEnabled = pref.getBoolPref(PREF_XPINSTALL_ENABLED);
+      this.xpinstallLocked = pref.prefIsLocked(PREF_XPINSTALL_ENABLED);
+    }
+    catch (e) {
+    }
+    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
+                              .getService(Components.interfaces.nsIIOService);
+    if (ioService.offline)
+      document.documentElement.currentPage =
+        document.getElementById("offline");
+    else
+      document.documentElement.currentPage =
+        document.getElementById("versioninfo");
   },
-  
+
   onWizardFinish: function ()
   {
     var pref = Components.classes["@mozilla.org/preferences-service;1"]
                          .getService(Components.interfaces.nsIPrefBranch);
     if (this.shouldSuggestAutoChecking)
-      pref.setBoolPref(PREF_UPDATE_EXTENSIONS_ENABLED, this.shouldAutoCheck); 
+      pref.setBoolPref(PREF_UPDATE_EXTENSIONS_ENABLED, this.shouldAutoCheck);
   },
-  
+
   _setUpButton: function (aButtonID, aButtonKey, aDisabled)
   {
     var strings = document.getElementById("updateStrings");
@@ -69,15 +73,15 @@ var gUpdateWizard = {
     if (aButtonKey) {
       button.label = strings.getString(aButtonKey);
       try {
-        button.accesskey = strings.getString(aButtonKey + "Accesskey");
+        button.setAttribute("accesskey", strings.getString(aButtonKey + "Accesskey"));
       }
       catch (e) {
       }
     }
     button.disabled = aDisabled;
   },
-  
-  setButtonLabels: function (aBackButton, aBackButtonIsDisabled, 
+
+  setButtonLabels: function (aBackButton, aBackButtonIsDisabled,
                              aNextButton, aNextButtonIsDisabled,
                              aCancelButton, aCancelButtonIsDisabled)
   {
@@ -85,31 +89,33 @@ var gUpdateWizard = {
     this._setUpButton("next", aNextButton, aNextButtonIsDisabled);
     this._setUpButton("cancel", aCancelButton, aCancelButtonIsDisabled);
   },
-  
+
   /////////////////////////////////////////////////////////////////////////////
   // Update Errors
   errorItems: [],
   showErrors: function (aState, aErrors)
   {
-    openDialog("chrome://mozapps/content/update/errors.xul", "", 
+    openDialog("chrome://mozapps/content/extensions/errors.xul", "",
                "modal", { state: aState, errors: aErrors });
   },
-  
+
+  // Displays a list of items that had an error during the update check. We
+  // don't display the actual error that occured since
+  // nsIAddonUpdateCheckListener doesn't return the error details.
   showUpdateCheckErrors: function ()
   {
     var errors = [];
     for (var i = 0; i < this.errorItems.length; ++i)
-      errors.push({ name: this.errorItems[i].name, error: true, 
-                    item: this.errorItems[i] });
+      errors.push({ name: this.errorItems[i].name, error: true });
     this.showErrors("checking", errors);
   },
 
   checkForErrors: function (aElementIDToShow)
   {
-    if (this.errorOnGeneric || this.errorItems.length > 0)
+    if (this.errorItems.length > 0)
       document.getElementById(aElementIDToShow).hidden = false;
   },
-  
+
   onWizardClose: function (aEvent)
   {
     if (gInstallingPage._installing) {
@@ -117,24 +123,39 @@ var gUpdateWizard = {
                          .getService(Components.interfaces.nsIObserverService);
       os.notifyObservers(null, "xpinstall-progress", "cancel");
       return false;
-    }    
+    }
     return true;
   }
 };
 
+var gOfflinePage = {
+  onPageAdvanced: function ()
+  {
+    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
+                              .getService(Components.interfaces.nsIIOService);
+    ioService.offline = false;
+    return true;
+  },
+
+  toggleOffline: function ()
+  {
+    var nextbtn = document.documentElement.getButton("next");
+    nextbtn.disabled = !nextbtn.disabled;
+  }
+}
+
 var gVersionInfoPage = {
   _completeCount: 0,
   _totalCount: 0,
   onPageShow: function ()
   {
-    gUpdateWizard.setButtonLabels(null, true, 
-                                  "nextButtonText", true, 
+    gUpdateWizard.setButtonLabels(null, true,
+                                  "nextButtonText", true,
                                   "cancelButtonText", false);
     var em = Components.classes["@mozilla.org/extensions/manager;1"]
-                       .getService(Components.interfaces.nsIExtensionManager);
-    // Synchronize the app compatibility info for all items by specifying 2 for
-    // the versionUpdateOnly parameter.
-    em.update([], 0, 2, this);
+                       .getService(nsIExtensionManager);
+    // Synchronize the app compatibility info for all items.
+    em.update([], 0, nsIExtensionManager.UPDATE_SYNC_COMPATIBILITY, this);
   },
 
   /////////////////////////////////////////////////////////////////////////////
@@ -142,17 +163,21 @@ var gVersionInfoPage = {
   onUpdateStarted: function() {
     this._totalCount = gUpdateWizard.items.length;
   },
-  
+
   onUpdateEnded: function() {
     var em = Components.classes["@mozilla.org/extensions/manager;1"]
-                       .getService(Components.interfaces.nsIExtensionManager);
+                       .getService(nsIExtensionManager);
     // Retrieve the remaining incompatible items.
-    gUpdateWizard.items = em.getIncompatibleItemList(null, null,
-                                                     nsIUpdateItem.TYPE_ADDON,
+    gUpdateWizard.items = em.getIncompatibleItemList(null, null, null,
+                                                     nsIUpdateItem.TYPE_ANY,
                                                      true, { });
+    gUpdateWizard.items = gUpdateWizard.items.filter(function(item) {
+      return gUpdateWizard.inactiveItemIDs.indexOf(item.id) < 0;
+    });
+
     if (gUpdateWizard.items.length > 0) {
       // There are still incompatible addons, inform the user.
-      document.documentElement.currentPage = 
+      document.documentElement.currentPage =
         document.getElementById("mismatch");
     }
     else {
@@ -163,10 +188,10 @@ var gVersionInfoPage = {
       setTimeout(close, 0);
     }
   },
-  
+
   onAddonUpdateStarted: function(addon) {
   },
-  
+
   onAddonUpdateEnded: function(addon, status) {
     if (status == nsIAUCL.STATUS_VERSIONINFO) {
       for (var i = 0; i < gUpdateWizard.items.length; ++i) {
@@ -177,18 +202,27 @@ var gVersionInfoPage = {
         }
       }
     }
+    else if (status == nsIAUCL.STATUS_FAILURE)
+      gUpdateWizard.errorItems.push(addon);
+
     ++this._completeCount;
 
+    // Update the status text and progress bar
+    var updateStrings = document.getElementById("updateStrings");
+    var status = document.getElementById("versioninfo.status");
+    var statusString = updateStrings.getFormattedString("statusPrefix", [addon.name]);
+    status.setAttribute("value", statusString);
+
     // Update the status text and progress bar
     var progress = document.getElementById("versioninfo.progress");
     progress.mode = "normal";
     progress.value = Math.ceil((this._completeCount / this._totalCount) * 100);
   },
-  
+
   /////////////////////////////////////////////////////////////////////////////
   // nsISupports
   QueryInterface: function(iid) {
-    if (!iid.equals(Components.interfaces.nsIAddonUpdateCheckListener) && 
+    if (!iid.equals(Components.interfaces.nsIAddonUpdateCheckListener) &&
         !iid.equals(Components.interfaces.nsISupports))
       throw Components.results.NS_ERROR_NO_INTERFACE;
     return this;
@@ -198,8 +232,8 @@ var gVersionInfoPage = {
 var gMismatchPage = {
   onPageShow: function ()
   {
-    gUpdateWizard.setButtonLabels(null, true, 
-                                  "mismatchCheckNow", false, 
+    gUpdateWizard.setButtonLabels(null, true,
+                                  "mismatchCheckNow", false,
                                   "mismatchDontCheck", false);
     document.documentElement.getButton("next").focus();
 
@@ -214,187 +248,170 @@ var gMismatchPage = {
 };
 
 var gUpdatePage = {
+  _totalCount: 0,
   _completeCount: 0,
   onPageShow: function ()
   {
-    gUpdateWizard.setButtonLabels(null, true, 
-                                  "nextButtonText", true, 
+    if (!gUpdateWizard.xpinstallEnabled && gUpdateWizard.xpinstallLocked) {
+      document.documentElement.currentPage = document.getElementById("adminDisabled");
+      return;
+    }
+
+    gUpdateWizard.setButtonLabels(null, true,
+                                  "nextButtonText", true,
                                   "cancelButtonText", false);
     document.documentElement.getButton("next").focus();
 
     gUpdateWizard.errorItems = [];
-    
+
+    this._totalCount = gUpdateWizard.items.length;
     var em = Components.classes["@mozilla.org/extensions/manager;1"]
-                       .getService(Components.interfaces.nsIExtensionManager);
-    em.update(gUpdateWizard.items, gUpdateWizard.items.length, false, this);
+                       .getService(nsIExtensionManager);
+    em.update(gUpdateWizard.items, this._totalCount,
+              nsIExtensionManager.UPDATE_CHECK_NEWVERSION, this);
   },
 
   /////////////////////////////////////////////////////////////////////////////
   // nsIAddonUpdateCheckListener
   onUpdateStarted: function() {
   },
-  
+
   onUpdateEnded: function() {
     var nextPage = document.getElementById("noupdates");
     if (gUpdateWizard.itemsToUpdate.length > 0)
       nextPage = document.getElementById("found");
     document.documentElement.currentPage = nextPage;
   },
-  
+
   onAddonUpdateStarted: function(addon) {
   },
-  
+
   onAddonUpdateEnded: function(addon, status) {
     if (status == nsIAUCL.STATUS_UPDATE)
       gUpdateWizard.itemsToUpdate.push(addon);
-    else if (status == nsIAUCL.STATE_ERROR)
+    else if (status == nsIAUCL.STATUS_FAILURE)
       gUpdateWizard.errorItems.push(addon);
-      
+
     ++this._completeCount;
 
     // Update the status text and progress bar
     var updateStrings = document.getElementById("updateStrings");
     var status = document.getElementById("checking.status");
-    var statusString = updateStrings.getFormattedString("checkingPrefix", [addon.name]);
+    var statusString = updateStrings.getFormattedString("statusPrefix", [addon.name]);
     status.setAttribute("value", statusString);
 
     var progress = document.getElementById("checking.progress");
-    progress.value = Math.ceil((this._completeCount / gUpdateWizard.items.length) * 100);
+    progress.value = Math.ceil((this._completeCount / this._totalCount) * 100);
   },
-  
+
   /////////////////////////////////////////////////////////////////////////////
   // nsISupports
   QueryInterface: function(iid) {
-    if (!iid.equals(Components.interfaces.nsIAddonUpdateCheckListener) && 
+    if (!iid.equals(Components.interfaces.nsIAddonUpdateCheckListener) &&
         !iid.equals(Components.interfaces.nsISupports))
       throw Components.results.NS_ERROR_NO_INTERFACE;
     return this;
   }
 };
- 
-var gFoundPage = {
-  _nonAppItems: [],
-  
-  _newestInfo: null,
 
-  buildAddons: function ()
+var gFoundPage = {
+  onPageShow: function ()
   {
-    var hasExtensions = false;
-    var foundAddonsList = document.getElementById("found.addons.list");
-    var uri = Components.classes["@mozilla.org/network/standard-url;1"]
-                        .createInstance(Components.interfaces.nsIURI);
+    gUpdateWizard.setButtonLabels(null, true,
+                                  "installButtonText", false,
+                                  null, false);
+
+    var foundUpdates = document.getElementById("found.updates");
     var itemCount = gUpdateWizard.itemsToUpdate.length;
     for (var i = 0; i < itemCount; ++i) {
       var item = gUpdateWizard.itemsToUpdate[i];
-      var checkbox = document.createElement("checkbox");
-      foundAddonsList.appendChild(checkbox);
-      checkbox.setAttribute("type", "update");
-      checkbox.label        = item.name + " " + item.version;
-      checkbox.setAttribute("URL", item.xpiURL);
-      checkbox.setAttribute("hash", item.xpiHash);
-      checkbox.infoURL      = "";
-      checkbox.internalName = "";
-      uri.spec              = item.xpiURL;
-      checkbox.setAttribute("source", uri.host);
-      checkbox.checked      = true;
-      hasExtensions         = true;
+      var listItem = foundUpdates.appendItem(item.name + " " + item.version,
+                                             item.xpiURL);
+      listItem.setAttribute("type", "checkbox");
+      listItem.setAttribute("checked", "true");
+      listItem.setAttribute("URL", item.xpiURL);
+      listItem.setAttribute("hash", item.xpiHash);
     }
 
-    if (hasExtensions) {
-      var addonsHeader = document.getElementById("addons");
-      var strings = document.getElementById("updateStrings");
-      addonsHeader.label = strings.getFormattedString("updateTypeExtensions", [itemCount]);
-      addonsHeader.collapsed = false;
+    if (!gUpdateWizard.xpinstallEnabled) {
+      document.getElementById("xpinstallDisabledAlert").hidden = false;
+      document.getElementById("enableXPInstall").focus();
+      document.documentElement.getButton("next").disabled = true;
+    }
+    else {
+      document.documentElement.getButton("next").focus();
+      document.documentElement.getButton("next").disabled = false;
     }
   },
 
-  _initialized: false,
-  onPageShow: function ()
+  toggleXPInstallEnable: function(aEvent)
   {
-    gUpdateWizard.setButtonLabels(null, true, 
-                                  "installButtonText", false, 
-                                  null, false);
-    document.documentElement.getButton("next").focus();
-    
-    var updates = document.getElementById("found.updates");
-    if (!this._initialized) {
-      this._initialized = true;
-      updates.computeSizes();
-      this.buildAddons();
-    }
-        
-    var kids = updates._getRadioChildren();
-    for (var i = 0; i < kids.length; ++i) {
-      if (kids[i].collapsed == false) {
-        updates.selectedIndex = i;
-        break;
-      }
-    }
+    var enabled = aEvent.target.checked;
+    gUpdateWizard.xpinstallEnabled = enabled;
+    var pref = Components.classes["@mozilla.org/preferences-service;1"]
+                         .getService(Components.interfaces.nsIPrefBranch);
+    pref.setBoolPref(PREF_XPINSTALL_ENABLED, enabled);
+    this.updateNextButton();
   },
-    
-  onSelect: function (aEvent)
+
+  updateNextButton: function ()
   {
-    var updates = document.getElementById("found.updates");
+    if (!gUpdateWizard.xpinstallEnabled) {
+      document.documentElement.getButton("next").disabled = true;
+      return;
+    }
+
     var oneChecked = false;
-    var items = updates.selectedItem.getElementsByTagName("checkbox");
-    for (var i = 0; i < items.length; ++i) {  
-      if (items[i].checked) {
-        oneChecked = true;
-        break;
-      }
+    var foundUpdates = document.getElementById("found.updates");
+    var updates = foundUpdates.getElementsByTagName("listitem");
+    for (var i = 0; i < updates.length; ++i) {
+      if (!updates[i].checked)
+        continue;
+      oneChecked = true;
+      break;
     }
 
-    var strings = document.getElementById("updateStrings");
-    gUpdateWizard.setButtonLabels(null, true, 
-                                  "installButtonText", true, 
+    gUpdateWizard.setButtonLabels(null, true,
+                                  "installButtonText", true,
                                   null, false);
-    var text = strings.getString("foundInstructions");
-    document.getElementById("found").setAttribute("next", "installing"); 
+    document.getElementById("found").setAttribute("next", "installing");
     document.documentElement.getButton("next").disabled = !oneChecked;
-
-    var foundInstructions = document.getElementById("foundInstructions");
-    while (foundInstructions.hasChildNodes())
-      foundInstructions.removeChild(foundInstructions.firstChild);
-    foundInstructions.appendChild(document.createTextNode(text));
   }
 };
 
 var gInstallingPage = {
   _installing       : false,
-  _restartRequired  : false,
   _objs             : [],
-  
+  _errors           : [],
+
   onPageShow: function ()
   {
-    gUpdateWizard.setButtonLabels(null, true, 
-                                  "nextButtonText", true, 
+    gUpdateWizard.setButtonLabels(null, true,
+                                  "nextButtonText", true,
                                   null, true);
 
-    // Get XPInstallManager and kick off download/install 
-    // process, registering us as an observer. 
+    // Get XPInstallManager and kick off download/install
+    // process, registering us as an observer.
     var items = [];
     var hashes = [];
     this._objs = [];
-    
-    this._restartRequired = false;
-    
-    gUpdateWizard.remainingExtensionUpdateCount = gUpdateWizard.itemsToUpdate.length;
+    this._errors = [];
 
-    var updates = document.getElementById("found.updates");
-    var checkboxes = updates.selectedItem.getElementsByTagName("checkbox");
-    for (var i = 0; i < checkboxes.length; ++i) {
-      if (checkboxes[i].type == "update" && checkboxes[i].checked) {
-        items.push(checkboxes[i].URL);
-        hashes.push(checkboxes[i].hash ? checkboxes[i].hash : null);
-        this._objs.push({ name: checkboxes[i].label });
-      }
+    var foundUpdates = document.getElementById("found.updates");
+    var updates = foundUpdates.getElementsByTagName("listitem");
+    for (var i = 0; i < updates.length; ++i) {
+      if (!updates[i].checked)
+        continue;
+      items.push(updates[i].value);
+      hashes.push(updates[i].getAttribute("hash") ? updates[i].getAttribute("hash") : null);
+      this._objs.push({ name: updates[i].label });
     }
-    
+
     var xpimgr = Components.classes["@mozilla.org/xpinstall/install-manager;1"]
                            .createInstance(Components.interfaces.nsIXPInstallManager);
     xpimgr.initManagerWithHashes(items, hashes, items.length, this);
   },
-  
+
   /////////////////////////////////////////////////////////////////////////////
   // nsIXPIProgressDialog
   onStateChange: function (aIndex, aState, aValue)
@@ -417,26 +434,22 @@ var gInstallingPage = {
       break;
     case nsIXPIProgressDialog.INSTALL_DONE:
       switch (aValue) {
-      case 999: 
-        this._restartRequired = true;
-        break;
-      case 0: 
-        --gUpdateWizard.remainingExtensionUpdateCount;
+      case 999:
+      case 0:
         break;
+      default:
+        this._errors.push({ name: this._objs[aIndex].name, error: aValue });
       }
       break;
     case nsIXPIProgressDialog.DIALOG_CLOSE:
       this._installing = false;
-      var nextPage = this._errors ? "errors" : (this._restartRequired ? "restart" : "finished");
+      var nextPage = this._errors.length > 0 ? "installerrors" : "finished";
       document.getElementById("installing").setAttribute("next", nextPage);
       document.documentElement.advance();
       break;
     }
   },
-  
-  _objs: [],
-  _errors: false,
-  
+
   onProgress: function (aIndex, aValue, aMaxValue)
   {
     var downloadProgress = document.getElementById("downloadProgress");
@@ -444,67 +457,63 @@ var gInstallingPage = {
   }
 };
 
-var gErrorsPage = {
+var gInstallErrorsPage = {
   onPageShow: function ()
   {
+    gUpdateWizard.setButtonLabels(null, true, null, true, null, true);
     document.documentElement.getButton("finish").focus();
-    gUpdateWizard.succeeded = false;
   },
-  
+
   onShowErrors: function ()
   {
-    gUpdateWizard.showErrors("install", gInstallingPage._objs);
-  }  
+    gUpdateWizard.showErrors("install", gInstallingPage._errors);
+  }
 };
 
+// Displayed when there are incompatible add-ons and the xpinstall.enabled
+// pref is false and locked.
+var gAdminDisabledPage = {
+  onPageShow: function ()
+  {
+    gUpdateWizard.setButtonLabels(null, true, null, true,
+                                  "cancelButtonText", true);
+    document.documentElement.getButton("finish").focus();
+  }
+};
+
+// Displayed when selected add-on updates have been installed without error.
+// There can still be add-ons that are not compatible and don't have an update.
 var gFinishedPage = {
   onPageShow: function ()
   {
     gUpdateWizard.setButtonLabels(null, true, null, true, null, true);
     document.documentElement.getButton("finish").focus();
-    
-    var iR = document.getElementById("incompatibleRemaining");
-    var iR2 = document.getElementById("incompatibleRemaining2");
-    var fEC = document.getElementById("finishedEnableChecking");
 
     if (gUpdateWizard.shouldSuggestAutoChecking) {
-      iR.hidden = true;
-      iR2.hidden = false;
-      fEC.hidden = false;
-      fEC.click();
-    }
-    else {
-      iR.hidden = false;
-      iR2.hidden = true;
-      fEC.hidden = true;
-    }
-    
-    if (gShowMismatch) {
-      document.getElementById("finishedMismatch").hidden = false;
-      document.getElementById("incompatibleAlert").hidden = false;
+      document.getElementById("finishedCheckDisabled").hidden = false;
+      gUpdateWizard.shouldAutoCheck = true;
     }
+    else
+      document.getElementById("finishedCheckEnabled").hidden = false;
+
+    document.documentElement.getButton("finish").focus();
   }
 };
 
+// Displayed when there are incompatible add-ons and there are no available
+// updates.
 var gNoUpdatesPage = {
   onPageShow: function (aEvent)
   {
     gUpdateWizard.setButtonLabels(null, true, null, true, null, true);
-    document.documentElement.getButton("finish").focus();
-    if (gShowMismatch) {
-      document.getElementById("introUser").hidden = true;
-      document.getElementById("introMismatch").hidden = false;
-      document.getElementById("mismatchNoUpdates").hidden = false;
-        
-      if (gUpdateWizard.shouldSuggestAutoChecking) {
-        document.getElementById("mismatchIncompatibleRemaining").hidden = true;
-        document.getElementById("mismatchIncompatibleRemaining2").hidden = false;
-        document.getElementById("mismatchFinishedEnableChecking").hidden = false;
-      }
+    if (gUpdateWizard.shouldSuggestAutoChecking) {
+      document.getElementById("noupdatesCheckDisabled").hidden = false;
+      gUpdateWizard.shouldAutoCheck = true;
     }
+    else
+      document.getElementById("noupdatesCheckEnabled").hidden = false;
 
-    gUpdateWizard.succeeded = false;
     gUpdateWizard.checkForErrors("updateCheckErrorNotFound");
+    document.documentElement.getButton("finish").focus();
   }
 };
-
